@@ -1,16 +1,14 @@
 from abc import ABC, abstractmethod
-from typing import Any, Tuple
 
 
 class RoutingService(ABC):
     """Interface for query routing services."""
 
     @abstractmethod
-    async def route_query(self, query: str) -> Tuple[str, Any]:
+    async def route_query(self, query: str) -> str:
         """Route a query to the appropriate agent.
 
         Args:
-            user_id: User ID
             query: User query
 
         Returns:
